@@ -1,12 +1,12 @@
 ;;; -*- emacs-lisp -*-
 ;;; scrreprt.el -- AUC TeX style for scrreprt.cls
 
-;; Copyright (C) 2002 Free Software Foundation
+;; Copyright (C) 2002, 2005 Free Software Foundation
 ;; License: GPL, see the file COPYING in the base directory of AUCTeX
 
 ;; Author: Mark Trettin <Mark.Trettin@gmx.de>
 ;; Created: 2002-09-26
-;; Version: $Id: scrreprt.el,v 1.7 2008/07/23 07:22:57 stephent Exp $
+;; Version: $Id: scrreprt.el,v 1.1.2.1 2008/09/09 21:55:12 matsl Exp $
 ;; Keywords: tex
 
 ;;; Commentary:
@@ -20,7 +20,7 @@
 (TeX-add-style-hook
  "scrreprt"
  (lambda ()
-   (setq LaTeX-largest-level (LaTeX-section-level "chapter"))
+   (LaTeX-largest-level-set "chapter")
    ;; load basic definitons
    (TeX-run-style-hooks "scrbase")
    (TeX-add-symbols
@@ -30,10 +30,7 @@
     '("setpartpreamble" [ TeX-arg-KOMA-setpreamble ] [ "Width" ] t)
     '("setchapterpreamble" [ TeX-arg-KOMA-setpreamble ] [ "Width" ] t)
     '("dictum" [ "Author" ] t))
-   (make-local-variable 'LaTeX-section-list)
-   (setq LaTeX-section-list (append
-			     LaTeX-section-list
-			     '(("addchap" 1))))
+   (LaTeX-section-list-add-locally '("addchap" 1))
    (make-local-variable 'LaTeX-section-label)
    (setq LaTeX-section-label (append
 			      LaTeX-section-label
@@ -49,8 +46,8 @@
 		     "setchapterpreamble"
 		     "dictum")))
      (font-latex-match-textual-make)
-     ;; Title keywords
-     (add-to-list 'font-latex-match-title-1-keywords-local "addchap")
-     (font-latex-match-title-1-make))))
+     ;; Sectioning keywords
+     (add-to-list 'font-latex-match-sectioning-1-keywords-local "addchap")
+     (font-latex-match-sectioning-1-make))))
 
 ;;; scrreprt.el ends here
